
import React from 'react';
import { motion } from 'framer-motion';
import { Button } from '@/components/ui/button';
import { Send, Bike, Smile } from 'lucide-react';
import { Input } from '@/components/ui/input';
import { Textarea } from '@/components/ui/textarea';
import { Label } from '@/components/ui/label';
import { useToast } from '@/components/ui/use-toast';


const CareerSection = () => {
  const { toast } = useToast();

  const handleSubmit = (e) => {
    e.preventDefault();
    toast({
      title: "Başvurunuz Alındı!",
      description: "En kısa sürede sizinle iletişime geçeceğiz.",
      variant: "success",
      duration: 5000,
    });
    e.target.reset();
  };

  return (
    <section id="career" className="py-16 md:py-24 bg-gradient-to-br from-red-700 via-pink-600 to-purple-700">
      <div className="container mx-auto px-4">
        <motion.h2
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6 }}
          className="text-4xl md:text-5xl font-bold text-center text-yellow-400 mb-6"
        >
          Ekibimize Katılın!
        </motion.h2>
        <motion.p 
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6, delay:0.1 }}
          className="text-center text-white/90 mb-12 max-w-2xl mx-auto text-lg"
        >
          Enerjik, bisiklet tutkunu ve markaların sesini duyurmaya hevesliysen, seni aramızda görmekten mutluluk duyarız! Aşağıdaki formu doldurarak bize ulaşabilirsin.
        </motion.p>

        <div className="grid md:grid-cols-2 gap-12 items-start">
          <motion.div 
            className="space-y-6"
            initial={{ opacity: 0, x: -30 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.7 }}
          >
            <div className="flex items-start p-6 bg-white/10 backdrop-blur-md rounded-xl border border-white/20">
              <Bike size={40} className="text-yellow-400 mr-4 mt-1" />
              <div>
                <h3 className="text-2xl font-semibold text-white mb-2">Neden Biz?</h3>
                <p className="text-white/80 leading-relaxed">Dinamik bir çalışma ortamı, esnek saatler ve şehrin enerjisini hissetme fırsatı sunuyoruz. Bisikletinle para kazanırken eğlenmek ister misin?</p>
              </div>
            </div>
            <div className="flex items-start p-6 bg-white/10 backdrop-blur-md rounded-xl border border-white/20">
              <Smile size={40} className="text-yellow-400 mr-4 mt-1" />
              <div>
                <h3 className="text-2xl font-semibold text-white mb-2">Aradığımız Özellikler</h3>
                <ul className="list-disc list-inside text-white/80 space-y-1">
                  <li>Bisiklet sürmeyi seven ve trafik kurallarına hakim</li>
                  <li>İletişim becerileri güçlü, güler yüzlü</li>
                  <li>Sorumluluk sahibi ve dakik</li>
                  <li>Takım çalışmasına yatkın</li>
                </ul>
              </div>
            </div>
             <div className="w-full h-64 rounded-xl overflow-hidden shadow-xl border-2 border-yellow-400/30">
               <img  class="w-full h-full object-cover" alt="Happy cyclist team posing for a photo" src="https://images.unsplash.com/photo-1591122275115-07371d7026f9" />
            </div>
          </motion.div>

          <motion.form
            onSubmit={handleSubmit}
            className="space-y-6 p-8 bg-white/10 backdrop-blur-lg rounded-2xl shadow-xl border border-white/20"
            initial={{ opacity: 0, x: 30 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.7 }}
          >
            <div>
              <Label htmlFor="name" className="text-yellow-400 font-medium">Adınız Soyadınız</Label>
              <Input id="name" name="name" type="text" placeholder="John Doe" required className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-2" />
            </div>
            <div>
              <Label htmlFor="email" className="text-yellow-400 font-medium">E-posta Adresiniz</Label>
              <Input id="email" name="email" type="email" placeholder="john.doe@example.com" required className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-2" />
            </div>
            <div>
              <Label htmlFor="phone" className="text-yellow-400 font-medium">Telefon Numaranız</Label>
              <Input id="phone" name="phone" type="tel" placeholder="05XX XXX XX XX" className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-2" />
            </div>
            <div>
              <Label htmlFor="message" className="text-yellow-400 font-medium">Neden Bizimle Çalışmak İstiyorsunuz?</Label>
              <Textarea id="message" name="message" placeholder="Kısaca kendinizden ve motivasyonunuzdan bahsedin..." required rows={4} className="bg-white/20 border-white/30 text-white placeholder:text-white/60 focus:border-yellow-400 focus:ring-yellow-400 mt-2" />
            </div>
            <Button type="submit" size="lg" className="w-full bg-gradient-to-r from-yellow-400 to-orange-500 text-purple-900 font-bold hover:from-yellow-500 hover:to-orange-600 transition-all duration-300 transform hover:scale-105 shadow-xl py-3 text-lg rounded-full group">
              Başvurunu Gönder
              <Send size={20} className="ml-2 transition-transform duration-300 group-hover:translate-x-1" />
            </Button>
          </motion.form>
        </div>
      </div>
    </section>
  );
};

export default CareerSection;
